# Generated by Django 2.1.2 on 2018-11-03 20:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djams', '0003_auto_20181023_2302'),
    ]

    operations = [
        migrations.AddField(
            model_name='adm_app',
            name='description',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Description'),
        ),
    ]
