# Generated by Django 2.1.1 on 2018-10-23 22:02

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djams', '0002_mds_partytype_partyclass'),
    ]

    operations = [
        migrations.RenameField(
            model_name='mds_taxtype',
            old_name='generic_tax_type_abbreviation',
            new_name='generic_tax_type_abbr',
        ),
    ]
