# Generated by Django 2.1.1 on 2018-10-21 22:38

from django.conf import settings
import django.contrib.auth.models
import django.contrib.auth.validators
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('sessions', '0001_initial'),
        ('auth', '0009_alter_user_last_name_max_length'),
    ]

    operations = [
        migrations.CreateModel(
            name='ADM_CustomUser',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('password', models.CharField(max_length=128, verbose_name='password')),
                ('last_login', models.DateTimeField(blank=True, null=True, verbose_name='last login')),
                ('is_superuser', models.BooleanField(default=False, help_text='Designates that this user has all permissions without explicitly assigning them.', verbose_name='superuser status')),
                ('username', models.CharField(error_messages={'unique': 'A user with that username already exists.'}, help_text='Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.', max_length=150, unique=True, validators=[django.contrib.auth.validators.UnicodeUsernameValidator()], verbose_name='username')),
                ('first_name', models.CharField(blank=True, max_length=30, verbose_name='first name')),
                ('last_name', models.CharField(blank=True, max_length=150, verbose_name='last name')),
                ('email', models.EmailField(blank=True, max_length=254, verbose_name='email address')),
                ('is_staff', models.BooleanField(default=False, help_text='Designates whether the user can log into this admin site.', verbose_name='staff status')),
                ('is_active', models.BooleanField(default=True, help_text='Designates whether this user should be treated as active. Unselect this instead of deleting accounts.', verbose_name='active')),
                ('date_joined', models.DateTimeField(default=django.utils.timezone.now, verbose_name='date joined')),
                ('groups', models.ManyToManyField(blank=True, help_text='The groups this user belongs to. A user will get all permissions granted to each of their groups.', related_name='user_set', related_query_name='user', to='auth.Group', verbose_name='groups')),
                ('user_permissions', models.ManyToManyField(blank=True, help_text='Specific permissions for this user.', related_name='user_set', related_query_name='user', to='auth.Permission', verbose_name='user permissions')),
            ],
            managers=[
                ('objects', django.contrib.auth.models.UserManager()),
            ],
        ),
        migrations.CreateModel(
            name='ADM_App',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=200, verbose_name='App Name')),
                ('django_app_name', models.CharField(error_messages={'unique': 'This django_app_name has already been taken.'}, max_length=150, null=True, unique=True, verbose_name='Django App Name')),
                ('version', models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True, verbose_name='App Version')),
                ('user_launch_view', models.CharField(blank=True, max_length=200, null=True, verbose_name='Launch View')),
                ('launch_url', models.URLField(blank=True, null=True)),
                ('launch_local_url', models.URLField(blank=True, null=True)),
                ('launch_dev_url', models.URLField(blank=True, null=True)),
                ('launch_qa_url', models.URLField(blank=True, null=True)),
                ('launch_uat_url', models.URLField(blank=True, null=True)),
                ('launch_prod_url', models.URLField(blank=True, null=True)),
                ('support_start_date', models.DateField(blank=True, null=True, verbose_name='Support Start Date')),
                ('support_end_date', models.DateField(blank=True, null=True, verbose_name='Support End Date')),
                ('creation_date', models.DateField(auto_now_add=True)),
                ('last_update_date', models.DateField(auto_now=True)),
                ('app_thumbnail', models.ImageField(upload_to='app_thumbnails/')),
            ],
        ),
        migrations.CreateModel(
            name='ADM_App_Data_Dest',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('folder_identifier', models.CharField(blank=True, max_length=200, null=True)),
                ('file_descriptor', models.CharField(blank=True, max_length=200, null=True)),
                ('relevant_model', models.CharField(max_length=200)),
                ('use_django_app_model_prefix', models.BooleanField(default=True)),
                ('custom_upload_query', models.CharField(blank=True, max_length=1000, null=True)),
                ('app', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='app_data_desc_to_app', to='djams.ADM_App')),
            ],
        ),
        migrations.CreateModel(
            name='ADM_AppCategory',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('keyword', models.CharField(blank=True, max_length=150, null=True)),
                ('creation_date', models.DateField(auto_now_add=True)),
                ('last_update_date', models.DateField(auto_now=True)),
            ],
        ),
        migrations.CreateModel(
            name='ADM_AppCategoryType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('description', models.CharField(max_length=200)),
                ('creation_date', models.DateField(auto_now_add=True)),
                ('last_update_date', models.DateField(auto_now=True)),
                ('creation_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='appcategorytype_creator', to=settings.AUTH_USER_MODEL)),
                ('last_update_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='appcategorytype_updater', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='ADM_AppRole',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=200)),
                ('creation_date', models.DateField(auto_now_add=True)),
                ('last_update_date', models.DateField(auto_now=True)),
                ('creation_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='approle_creator', to=settings.AUTH_USER_MODEL)),
                ('last_update_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='approle_updater', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['name'],
            },
        ),
        migrations.CreateModel(
            name='ADM_AppSession',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('token', models.CharField(blank=True, max_length=150, null=True)),
                ('username', models.CharField(blank=True, max_length=100, null=True)),
                ('app_name', models.CharField(blank=True, max_length=150, null=True)),
                ('event_time', models.DateTimeField(blank=True, null=True)),
                ('user_ip', models.CharField(blank=True, max_length=100, null=True)),
                ('app', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='appsession_app', to='djams.ADM_App')),
            ],
        ),
        migrations.CreateModel(
            name='ADM_AppSessionAudit',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('token', models.CharField(blank=True, max_length=150, null=True)),
                ('username', models.CharField(blank=True, max_length=100, null=True)),
                ('app_name', models.CharField(blank=True, max_length=150, null=True)),
                ('event_time', models.DateTimeField(blank=True, null=True)),
                ('event_result', models.CharField(blank=True, max_length=100, null=True)),
                ('operating_username', models.CharField(blank=True, max_length=150, null=True)),
                ('process', models.CharField(blank=True, max_length=100, null=True)),
                ('user_ip', models.CharField(blank=True, max_length=100, null=True)),
                ('activity_desc', models.CharField(blank=True, max_length=300, null=True)),
                ('app', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='appsessionaudit_app', to='djams.ADM_App')),
            ],
        ),
        migrations.CreateModel(
            name='ADM_Authority',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('regions_used', models.BooleanField(default=False)),
                ('groups_used', models.BooleanField(default=False)),
                ('valid_from_date', models.DateField(blank=True, null=True)),
                ('valid_to_date', models.DateField(blank=True, null=True)),
                ('current', models.BooleanField(default=True)),
                ('creation_date', models.DateField(auto_now_add=True)),
                ('last_update_date', models.DateField(auto_now=True)),
                ('app', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='authority_app', to='djams.ADM_App')),
            ],
            options={
                'ordering': ['client', 'user', 'app'],
            },
        ),
        migrations.CreateModel(
            name='ADM_DevTeam',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=200)),
                ('creation_date', models.DateField(auto_now_add=True)),
                ('last_update_date', models.DateField(auto_now=True)),
                ('creation_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='devteam_creator', to=settings.AUTH_USER_MODEL)),
                ('deputy_team_lead', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='devteam_dep_lead_user', to=settings.AUTH_USER_MODEL)),
                ('last_update_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='devteam_updater', to=settings.AUTH_USER_MODEL)),
                ('team_lead', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='devteam_lead_user', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='ADM_EnquiryMessage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('message', models.TextField(max_length=2000, null=True)),
                ('message_read', models.BooleanField(default='False')),
                ('team_responded', models.BooleanField(default=False)),
                ('enquirer_responded', models.BooleanField(default=False)),
                ('creation_date', models.DateField(auto_now_add=True)),
                ('last_update_date', models.DateField(auto_now=True)),
                ('creation_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='enquirymessage_creator', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['creation_date'],
            },
        ),
        migrations.CreateModel(
            name='ADM_EnquiryStatus',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=200)),
                ('creation_date', models.DateField(auto_now_add=True)),
                ('last_update_date', models.DateField(auto_now=True)),
                ('creation_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='enquiry_status_creator', to=settings.AUTH_USER_MODEL)),
                ('last_update_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='enquiry_status_updater', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='ADM_EventType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=50)),
                ('description', models.CharField(max_length=200, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='ADM_HelpPage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=200)),
                ('narrative', models.CharField(blank=True, max_length=4000, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='ADM_SelfServiceUser',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('email', models.CharField(max_length=200)),
                ('first_name', models.CharField(max_length=100)),
                ('last_name', models.CharField(max_length=100)),
                ('dev_account', models.CharField(max_length=100)),
                ('creation_date', models.DateField(auto_now_add=True)),
                ('last_update_date', models.DateField(auto_now=True)),
                ('creation_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='selfserviceuser_creator', to=settings.AUTH_USER_MODEL)),
                ('dev_team', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='selfserviceuser_devteam', to='djams.ADM_DevTeam')),
                ('last_update_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='selfserviceuser_updater', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='ADM_Subscription',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('subscription_paid', models.BooleanField(default=False)),
                ('amount_paid', models.DecimalField(decimal_places=2, max_digits=38)),
                ('uses_regions', models.BooleanField(default=True)),
                ('uses_groups', models.BooleanField(default=True)),
                ('start_date', models.DateField(blank=True, null=True)),
                ('end_date', models.DateField(blank=True, null=True)),
                ('currently_subscribed', models.BooleanField(blank=True, null=True)),
                ('creation_date', models.DateField(auto_now_add=True)),
                ('last_update_date', models.DateField(auto_now=True)),
                ('app', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='subscription_solution', to='djams.ADM_App')),
            ],
            options={
                'ordering': ['app'],
            },
        ),
        migrations.CreateModel(
            name='ADM_SubscriptionType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=200)),
                ('length', models.CharField(blank=True, choices=[('m', 'Monthly'), ('a', 'Annual'), ('c', 'Custom Fee')], max_length=2, null=True)),
                ('days_subscribed', models.IntegerField(blank=True, null=True)),
                ('creation_date', models.DateField(auto_now_add=True)),
                ('last_update_date', models.DateField(auto_now=True)),
                ('creation_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='subscriptiontype_creator', to=settings.AUTH_USER_MODEL)),
                ('last_update_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='subscriptiontype_updater', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['name'],
            },
        ),
        migrations.CreateModel(
            name='ADM_Team',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=200)),
                ('creation_date', models.DateField(auto_now_add=True)),
                ('last_update_date', models.DateField(auto_now=True)),
                ('creation_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='team_creator', to=settings.AUTH_USER_MODEL)),
                ('deputy_team_lead', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='dep_team_lead_user', to=settings.AUTH_USER_MODEL)),
                ('last_update_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='team_updater', to=settings.AUTH_USER_MODEL)),
                ('team_lead', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='team_lead_user', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='ADM_UserAppRole',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('creation_date', models.DateField(auto_now_add=True)),
                ('last_update_date', models.DateField(auto_now=True)),
                ('app', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='userapprole_app', to='djams.ADM_App')),
                ('creation_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='userapprole_creator', to=settings.AUTH_USER_MODEL)),
                ('last_update_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='userapprole_updater', to=settings.AUTH_USER_MODEL)),
                ('role', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='userapprole_role', to='djams.ADM_AppRole')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='userapprole_user', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['user', 'app', 'role'],
            },
        ),
        migrations.CreateModel(
            name='ADM_UserEnquiry',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('reference', models.TextField(blank=True, max_length=50, null=True)),
                ('details', models.TextField(help_text='Enter your enquiry here', max_length=2000, null=True)),
                ('status_datetime_changed', models.DateTimeField(blank=True, null=True)),
                ('opened_date', models.DateField(auto_now=True)),
                ('closed_date', models.DateField(blank=True, null=True)),
                ('creation_date', models.DateField(auto_now_add=True)),
                ('name', models.CharField(max_length=200)),
                ('last_update_date', models.DateField(auto_now=True)),
                ('app', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='userenquiry_app', to='djams.ADM_App')),
            ],
        ),
        migrations.CreateModel(
            name='ADM_UserProfile',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('avatar', models.ImageField(blank=True, default='user_thumbnails/default.jpg', null=True, upload_to='')),
                ('creation_date', models.DateField(auto_now_add=True)),
                ('last_update_date', models.DateField(auto_now=True)),
                ('require_password_reset', models.BooleanField(default='False')),
                ('invalid_login_attempts', models.IntegerField(blank=True, default=0, null=True)),
                ('password_change_date', models.DateField(blank=True, null=True)),
                ('pp1', models.TextField(blank=True, max_length=128, null=True)),
                ('ps1', models.TextField(blank=True, max_length=128, null=True)),
                ('pp2', models.TextField(blank=True, max_length=128, null=True)),
                ('ps2', models.TextField(blank=True, max_length=128, null=True)),
                ('pp3', models.TextField(blank=True, max_length=128, null=True)),
                ('ps3', models.TextField(blank=True, max_length=128, null=True)),
                ('pp4', models.TextField(blank=True, max_length=128, null=True)),
                ('ps4', models.TextField(blank=True, max_length=128, null=True)),
                ('pp5', models.TextField(blank=True, max_length=128, null=True)),
                ('ps5', models.TextField(blank=True, max_length=128, null=True)),
                ('pp6', models.TextField(blank=True, max_length=128, null=True)),
                ('ps6', models.TextField(blank=True, max_length=128, null=True)),
                ('pp7', models.TextField(blank=True, max_length=128, null=True)),
                ('ps7', models.TextField(blank=True, max_length=128, null=True)),
                ('pp8', models.TextField(blank=True, max_length=128, null=True)),
                ('ps8', models.TextField(blank=True, max_length=128, null=True)),
                ('pp9', models.TextField(blank=True, max_length=128, null=True)),
                ('ps9', models.TextField(blank=True, max_length=128, null=True)),
                ('pp10', models.TextField(blank=True, max_length=128, null=True)),
                ('ps10', models.TextField(blank=True, max_length=128, null=True)),
                ('pp11', models.TextField(blank=True, max_length=128, null=True)),
                ('ps11', models.TextField(blank=True, max_length=128, null=True)),
                ('pp12', models.TextField(blank=True, max_length=128, null=True)),
                ('ps12', models.TextField(blank=True, max_length=128, null=True)),
                ('pp13', models.TextField(blank=True, max_length=128, null=True)),
                ('ps13', models.TextField(blank=True, max_length=128, null=True)),
                ('pp14', models.TextField(blank=True, max_length=128, null=True)),
                ('ps14', models.TextField(blank=True, max_length=128, null=True)),
                ('pp15', models.TextField(blank=True, max_length=128, null=True)),
                ('ps15', models.TextField(blank=True, max_length=128, null=True)),
                ('pp16', models.TextField(blank=True, max_length=128, null=True)),
                ('ps16', models.TextField(blank=True, max_length=128, null=True)),
                ('pp17', models.TextField(blank=True, max_length=128, null=True)),
                ('ps17', models.TextField(blank=True, max_length=128, null=True)),
                ('pp18', models.TextField(blank=True, max_length=128, null=True)),
                ('ps18', models.TextField(blank=True, max_length=128, null=True)),
                ('pp19', models.TextField(blank=True, max_length=128, null=True)),
                ('ps19', models.TextField(blank=True, max_length=128, null=True)),
                ('pp20', models.TextField(blank=True, max_length=128, null=True)),
                ('ps20', models.TextField(blank=True, max_length=128, null=True)),
                ('pp21', models.TextField(blank=True, max_length=128, null=True)),
                ('ps21', models.TextField(blank=True, max_length=128, null=True)),
                ('pp22', models.TextField(blank=True, max_length=128, null=True)),
                ('ps22', models.TextField(blank=True, max_length=128, null=True)),
                ('pp23', models.TextField(blank=True, max_length=128, null=True)),
                ('ps23', models.TextField(blank=True, max_length=128, null=True)),
                ('creation_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='user_creator', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='ADM_UserSession',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('session', models.ForeignKey(db_constraint=False, on_delete=django.db.models.deletion.CASCADE, to='sessions.Session')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='MDS_ClientGroup',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=150)),
                ('description', models.CharField(max_length=150)),
                ('valid_from_date', models.DateField(blank=True, null=True)),
                ('valid_to_date', models.DateField(blank=True, null=True)),
                ('current', models.BooleanField(default=True)),
                ('creation_date', models.DateField(auto_now_add=True)),
                ('last_update_date', models.DateField(auto_now=True)),
            ],
            options={
                'ordering': ['name'],
            },
        ),
        migrations.CreateModel(
            name='MDS_ClientRegion',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=150)),
                ('description', models.CharField(max_length=150)),
                ('valid_from_date', models.DateField(blank=True, null=True)),
                ('valid_to_date', models.DateField(blank=True, null=True)),
                ('current', models.BooleanField(default=True)),
                ('creation_date', models.DateField(auto_now_add=True)),
                ('last_update_date', models.DateField(auto_now=True)),
            ],
            options={
                'ordering': ['name'],
            },
        ),
        migrations.CreateModel(
            name='MDS_Company',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('registered_name', models.CharField(max_length=200)),
                ('gfis_id', models.CharField(blank=True, max_length=50, null=True)),
                ('short_name', models.CharField(blank=True, max_length=40, null=True)),
                ('database_name', models.CharField(help_text='Enter the name of the client specific SQL database', max_length=200, unique=True)),
                ('logo', models.ImageField(blank=True, default='company_thumbnails/media.jpg', null=True, upload_to='company_thumbnails', verbose_name='Company Logo Thumbnail')),
                ('creation_date', models.DateField(auto_now_add=True)),
                ('last_update_date', models.DateField(auto_now=True)),
                ('creation_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='company_creator', to=settings.AUTH_USER_MODEL)),
                ('last_update_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='company_updater', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['registered_name'],
            },
        ),
        migrations.CreateModel(
            name='MDS_Country',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=200)),
                ('capital_city', models.CharField(blank=True, max_length=200, null=True)),
                ('iso_numeric', models.IntegerField(blank=True, null=True)),
                ('iso_alpha2', models.CharField(max_length=2)),
                ('iso_alpha3', models.CharField(max_length=3)),
                ('iso_version', models.CharField(max_length=30, null=True)),
                ('valid_from_date', models.DateField(blank=True)),
                ('valid_to_date', models.DateField(blank=True, null=True)),
                ('latest_version', models.BooleanField(default=False)),
                ('creation_date', models.DateField(auto_now_add=True)),
                ('last_update_date', models.DateField(auto_now=True)),
                ('creation_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='country_creator', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['id'],
            },
        ),
        migrations.CreateModel(
            name='MDS_CountryGroup',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=200)),
                ('abbreviation', models.CharField(blank=True, max_length=20, null=True)),
                ('creation_date', models.DateField(auto_now_add=True)),
                ('last_update_date', models.DateField(auto_now=True)),
                ('creation_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='countrygroup_creator', to=settings.AUTH_USER_MODEL)),
                ('last_update_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='countrygroup_updater', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='MDS_Currency',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=75)),
                ('iso_alpha3', models.CharField(blank=True, max_length=3, null=True)),
                ('iso_numeric', models.IntegerField(blank=True, null=True)),
                ('symbol', models.CharField(blank=True, max_length=20, null=True)),
                ('minor_unit', models.IntegerField(blank=True, null=True)),
                ('valid_from_date', models.DateField(blank=True, null=True)),
                ('valid_to_date', models.DateField(blank=True, null=True)),
                ('latest_version', models.BooleanField(default='True')),
                ('creation_date', models.DateField(auto_now_add=True)),
                ('last_update_date', models.DateField(auto_now=True)),
                ('country', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='currency_country', to='djams.MDS_Country')),
                ('creation_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='currency_creator', to=settings.AUTH_USER_MODEL)),
                ('last_update_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='currency_updater', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['name'],
            },
        ),
        migrations.CreateModel(
            name='MDS_FinancialInstrumentType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('generic_instrument_type_name', models.CharField(max_length=200)),
                ('generic_instrument_type_abbreviation', models.CharField(blank=True, max_length=20, null=True)),
                ('instrument_region', models.CharField(choices=[('n', 'National'), ('c', 'Continental'), ('i', 'International')], max_length=200)),
                ('tax_category', models.CharField(max_length=200, null=True)),
                ('region_specific_instrument_type_name', models.CharField(max_length=200, null=True)),
                ('specific_instrument_type_abbr', models.CharField(blank=True, max_length=20, null=True)),
                ('start_date', models.DateField(blank=True, null=True)),
                ('end_date', models.DateField(blank=True, null=True)),
                ('creation_date', models.DateField(auto_now_add=True)),
                ('last_update_date', models.DateField(auto_now=True)),
                ('creation_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='fininsttype_creator', to=settings.AUTH_USER_MODEL)),
                ('jurisdiction', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djams.MDS_Country')),
                ('last_update_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='fininsttype_updater', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='MDS_PartyClass',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('description', models.CharField(max_length=50)),
                ('creation_date', models.DateField(auto_now_add=True)),
                ('last_update_date', models.DateField(auto_now=True)),
                ('creation_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='partyclass_creator', to=settings.AUTH_USER_MODEL)),
                ('last_update_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='partyclass_updater', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='MDS_PartyType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('description', models.CharField(max_length=100)),
                ('abbreviation', models.CharField(max_length=20)),
                ('creation_date', models.DateField(auto_now_add=True)),
                ('last_update_date', models.DateField(auto_now=True)),
                ('country', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='partytype_country', to='djams.MDS_Country')),
                ('creation_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='partytype_creator', to=settings.AUTH_USER_MODEL)),
                ('last_update_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='partytype_updater', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='MDS_PublicBody',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=150)),
                ('description', models.CharField(blank=True, max_length=300, null=True)),
                ('creation_date', models.DateField(auto_now_add=True)),
                ('last_update_date', models.DateField(auto_now=True)),
            ],
        ),
        migrations.CreateModel(
            name='MDS_PublicBodyType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=150)),
                ('description', models.CharField(max_length=300)),
                ('creation_date', models.DateField(auto_now_add=True)),
                ('last_update_date', models.DateField(auto_now=True)),
                ('creation_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='publicbodytype_creator', to=settings.AUTH_USER_MODEL)),
                ('last_update_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='publicbodytype_updater', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='MDS_TaxType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('generic_tax_type_name', models.CharField(max_length=200)),
                ('generic_tax_type_abbreviation', models.CharField(blank=True, max_length=10, null=True)),
                ('tax_region', models.CharField(choices=[('l', 'Local Government Tax'), ('s', 'State Tax'), ('n', 'National/Federal Tax')], max_length=200)),
                ('tax_category', models.CharField(max_length=200, null=True)),
                ('region_specific_tax_type_name', models.CharField(max_length=200, null=True)),
                ('specific_tax_type_abbr', models.CharField(blank=True, max_length=10, null=True)),
                ('start_date', models.DateField(blank=True, null=True)),
                ('end_date', models.DateField(blank=True, null=True)),
                ('creation_date', models.DateField(auto_now_add=True)),
                ('last_update_date', models.DateField(auto_now=True)),
                ('creation_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='taxtype_creator', to=settings.AUTH_USER_MODEL)),
                ('jurisdiction', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djams.MDS_Country')),
                ('last_update_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='taxtype_updater', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='RDS_Company_Data_Ingest_Meta',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('file_name', models.CharField(blank=True, max_length=255, null=True)),
                ('upload_user', models.CharField(blank=True, max_length=100, null=True)),
                ('upload_username', models.CharField(blank=True, max_length=100, null=True)),
                ('client', models.CharField(blank=True, max_length=200, null=True)),
                ('django_app_name', models.CharField(blank=True, max_length=150, null=True)),
                ('event_datetime', models.DateTimeField(blank=True, null=True)),
                ('event_result', models.CharField(blank=True, max_length=100, null=True)),
                ('activity_desc', models.CharField(blank=True, max_length=300, null=True)),
            ],
        ),
        migrations.AddField(
            model_name='mds_publicbody',
            name='body_type',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='publicbody_publicbodytype', to='djams.MDS_PublicBodyType'),
        ),
        migrations.AddField(
            model_name='mds_publicbody',
            name='country',
            field=models.ManyToManyField(related_name='publicbody_country', to='djams.MDS_Country'),
        ),
        migrations.AddField(
            model_name='mds_publicbody',
            name='creation_user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='publicbody_creator', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='mds_publicbody',
            name='last_update_user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='publicbody_updater', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='mds_country',
            name='group_membership',
            field=models.ManyToManyField(to='djams.MDS_CountryGroup'),
        ),
        migrations.AddField(
            model_name='mds_country',
            name='last_update_user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='country_updater', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='mds_company',
            name='party_type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='party_party_type', to='djams.MDS_PartyType'),
        ),
        migrations.AddField(
            model_name='mds_company',
            name='registered_country',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='party_country', to='djams.MDS_Country'),
        ),
        migrations.AddField(
            model_name='mds_clientregion',
            name='client',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='clientregion_company', to='djams.MDS_Company'),
        ),
        migrations.AddField(
            model_name='mds_clientregion',
            name='countries',
            field=models.ManyToManyField(to='djams.MDS_Country'),
        ),
        migrations.AddField(
            model_name='mds_clientregion',
            name='creation_user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='clientregion_creator', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='mds_clientregion',
            name='last_update_user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='clientregion_updater', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='mds_clientgroup',
            name='client',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='clientgroup_company', to='djams.MDS_Company'),
        ),
        migrations.AddField(
            model_name='mds_clientgroup',
            name='countries',
            field=models.ManyToManyField(to='djams.MDS_Country'),
        ),
        migrations.AddField(
            model_name='mds_clientgroup',
            name='creation_user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='clientgroup_creator', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='mds_clientgroup',
            name='last_update_user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='clientgroup_updater', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='adm_userprofile',
            name='employer',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='user_employer', to='djams.MDS_Company'),
        ),
        migrations.AddField(
            model_name='adm_userprofile',
            name='employerco',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='employer_company', to='djams.MDS_Company'),
        ),
        migrations.AddField(
            model_name='adm_userprofile',
            name='last_update_user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='user_updater', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='adm_userprofile',
            name='resident_country',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='user_country', to='djams.MDS_Country'),
        ),
        migrations.AddField(
            model_name='adm_userprofile',
            name='user',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='adm_userenquiry',
            name='client',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='userenquiry_company', to='djams.MDS_Company'),
        ),
        migrations.AddField(
            model_name='adm_userenquiry',
            name='creation_user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='userenquiry_creator', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='adm_userenquiry',
            name='last_update_user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='userenquiry_status_updater', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='adm_userenquiry',
            name='status',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='userenquiry_enquirystatus', to='djams.ADM_EnquiryStatus'),
        ),
        migrations.AddField(
            model_name='adm_userenquiry',
            name='team',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='userenquiry_team', to='djams.ADM_Team'),
        ),
        migrations.AddField(
            model_name='adm_userenquiry',
            name='user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='userenquiry_user', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='adm_subscription',
            name='client',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='subscription_party', to='djams.MDS_Company'),
        ),
        migrations.AddField(
            model_name='adm_subscription',
            name='creation_user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='subscription_creator', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='adm_subscription',
            name='last_update_user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='subscription_updater', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='adm_subscription',
            name='subscription_paid_currency',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='subscription_currency', to='djams.MDS_Currency'),
        ),
        migrations.AddField(
            model_name='adm_subscription',
            name='subscription_type',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='substype_subs', to='djams.ADM_SubscriptionType'),
        ),
        migrations.AddField(
            model_name='adm_selfserviceuser',
            name='team',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='selfserviceuser_team', to='djams.ADM_Team'),
        ),
        migrations.AddField(
            model_name='adm_selfserviceuser',
            name='user',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='selfserviceuser_user', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='adm_enquirymessage',
            name='enquiry_thread',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='enquirymessage_userenquiry', to='djams.ADM_UserEnquiry'),
        ),
        migrations.AddField(
            model_name='adm_enquirymessage',
            name='last_update_user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='enquirymessage_updater', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='adm_enquirymessage',
            name='message_author',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='enquirymessage_user', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='adm_enquirymessage',
            name='team',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='enquirymessage_team', to='djams.ADM_Team'),
        ),
        migrations.AddField(
            model_name='adm_authority',
            name='client',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='authority_company', to='djams.MDS_Company'),
        ),
        migrations.AddField(
            model_name='adm_authority',
            name='client_group',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='authority_clientgroup', to='djams.MDS_ClientGroup'),
        ),
        migrations.AddField(
            model_name='adm_authority',
            name='client_region',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='authority_clientregion', to='djams.MDS_ClientRegion'),
        ),
        migrations.AddField(
            model_name='adm_authority',
            name='creation_user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='authority_creator', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='adm_authority',
            name='last_update_user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='authority_updater', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='adm_authority',
            name='subscription',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='authority_subscription', to='djams.ADM_Subscription'),
        ),
        migrations.AddField(
            model_name='adm_authority',
            name='user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='authority_user', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='adm_appsessionaudit',
            name='client',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='appsessionaudit_client', to='djams.MDS_Company'),
        ),
        migrations.AddField(
            model_name='adm_appsessionaudit',
            name='operating_user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='appsessionaudit_user', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='adm_appsessionaudit',
            name='user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='appsession_user_audit', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='adm_appsession',
            name='client',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='appsession_client', to='djams.MDS_Company'),
        ),
        migrations.AddField(
            model_name='adm_appsession',
            name='user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='appsession_user', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='adm_appcategory',
            name='app_category_type',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='appcategory_type', to='djams.ADM_AppCategoryType'),
        ),
        migrations.AddField(
            model_name='adm_appcategory',
            name='creation_user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='appcategory_creator', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='adm_appcategory',
            name='last_update_user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='appcategory_updater', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='adm_app',
            name='app_category',
            field=models.ManyToManyField(blank=True, to='djams.ADM_AppCategory', verbose_name='App Categories'),
        ),
        migrations.AddField(
            model_name='adm_app',
            name='billing_recipient',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='billing_recipient', to=settings.AUTH_USER_MODEL, verbose_name='Billing Recipient'),
        ),
        migrations.AddField(
            model_name='adm_app',
            name='creation_user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='app_creator', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='adm_app',
            name='finance_sme',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='finance_sme', to=settings.AUTH_USER_MODEL, verbose_name='Finance SME'),
        ),
        migrations.AddField(
            model_name='adm_app',
            name='instrument_category',
            field=models.ManyToManyField(blank=True, to='djams.MDS_FinancialInstrumentType', verbose_name='Financial Instrument Category'),
        ),
        migrations.AddField(
            model_name='adm_app',
            name='last_update_user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='app_updater', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='adm_app',
            name='sales_contact',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='sales_contact', to=settings.AUTH_USER_MODEL, verbose_name='Sales Contact'),
        ),
        migrations.AddField(
            model_name='adm_app',
            name='tax_sme',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='tax_sme', to=settings.AUTH_USER_MODEL, verbose_name='Tax SME'),
        ),
        migrations.AddField(
            model_name='adm_app',
            name='tax_type',
            field=models.ManyToManyField(blank=True, to='djams.MDS_TaxType', verbose_name='Tax Type'),
        ),
        migrations.AddField(
            model_name='adm_app',
            name='tech_expert',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='tech_solution_expert', to=settings.AUTH_USER_MODEL, verbose_name='Technology Solution Expert'),
        ),
    ]
