# Generated by Django 2.1.2 on 2018-11-04 16:01

import django.core.files.storage
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djams', '0006_auto_20181104_0115'),
    ]

    operations = [
        migrations.AlterField(
            model_name='adm_app',
            name='app_thumbnail',
            field=models.ImageField(storage=django.core.files.storage.FileSystemStorage(location='C:\\Users\\eburm\\Documents\\MEGA\\platform_code\\project_management\\../media'), upload_to='app_thumbnails'),
        ),
        migrations.AlterField(
            model_name='adm_app',
            name='description',
            field=models.CharField(blank=True, max_length=350, null=True, verbose_name='Description'),
        ),
    ]
