'''
App configuration information
'''

from django.apps import AppConfig


class DjamsConfig(AppConfig):
    'Verbose name and other settings for the django-plotly-dash application'
    name = 'djams'
    verbose_name = "Django Analytics Microsites"
