# Generated by Django 2.1.2 on 2018-11-05 23:12

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djams', '0007_auto_20181104_1601'),
    ]

    operations = [
        migrations.AddField(
            model_name='adm_team',
            name='team_members',
            field=models.ManyToManyField(related_name='team_members_users', to=settings.AUTH_USER_MODEL),
        ),
    ]
