# Generated by Django 2.1.2 on 2018-11-04 01:13

import django.core.files.storage
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djams', '0004_adm_app_description'),
    ]

    operations = [
        migrations.AlterField(
            model_name='adm_app',
            name='app_thumbnail',
            field=models.ImageField(storage=django.core.files.storage.FileSystemStorage(location='C:\\Users\\eburm\\Documents\\MEGA\\platform_code\\admin_portal\\../media\\app_thumbnails'), upload_to=''),
        ),
    ]
