# Generated by Django 2.1.1 on 2018-10-23 21:48

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djams', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='mds_partytype',
            name='partyclass',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='partytype_partyclass', to='djams.MDS_PartyClass'),
        ),
    ]
