from django.contrib import admin
from .models import *
from djams.models import *

# admin.site.register(MDS_TaxType)
# admin.site.register(ADM_AppCategoryType)
# admin.site.register(ADM_AppCategory)
# admin.site.register(ADM_App)
# admin.site.register(ADM_Authority)
# admin.site.register(MDS_PartyType)
# #admin.site.register(MDS_Party)
# admin.site.register(MDS_Company)
# admin.site.register(ADM_Subscription)
# admin.site.register(MDS_Country)

# admin.site.register(MDS_Currency)
# admin.site.register(ADM_SubscriptionType)
# admin.site.register(ADM_UserProfile)
# admin.site.register(MDS_ClientGroup)
# admin.site.register(MDS_ClientRegion)
# admin.site.register(MDS_CountryGroup)
# admin.site.register(ADM_EnquiryMessage)
# admin.site.register(ADM_UserEnquiry)
# admin.site.register(ADM_UserAppRole)
# admin.site.register(ADM_EnquiryStatus)
# admin.site.register(ADM_Team)

# admin.site.register(ADM_App_Data_Dest)
# admin.site.register(RDS_Company_Data_Ingest_Meta)


